# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from deep_lynx.api_client import ApiClient


class DataSourcesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive_data_source(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """Archive Data Source  # noqa: E501

        Archive a data source, with options to permanently remove it (and associated data).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_data_source(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str archive: Set to true to archive the data source.
        :param str force_delete: Set to true to force deletion of the data source.
        :param str remove_data: Set to true to remove data associated with the data source.
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.archive_data_source_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
        else:
            (data) = self.archive_data_source_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
            return data

    def archive_data_source_with_http_info(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """Archive Data Source  # noqa: E501

        Archive a data source, with options to permanently remove it (and associated data).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_data_source_with_http_info(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str archive: Set to true to archive the data source.
        :param str force_delete: Set to true to force deletion of the data source.
        :param str remove_data: Set to true to remove data associated with the data source.
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'data_source_id', 'archive', 'force_delete', 'remove_data']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_data_source" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `archive_data_source`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `archive_data_source`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501

        query_params = []
        if 'archive' in params:
            query_params.append(('archive', params['archive']))  # noqa: E501
        if 'force_delete' in params:
            query_params.append(('forceDelete', params['force_delete']))  # noqa: E501
        if 'remove_data' in params:
            query_params.append(('removeData', params['remove_data']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_data_source(self, body, container_id, **kwargs):  # noqa: E501
        """Create Data Source  # noqa: E501

        Create new datasource. Supported data source types are `http`, `standard` (or `manual`), `jazz`, and `aveva`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_data_source(body, container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateDataSourceRequest body: (required)
        :param str container_id: (required)
        :return: CreateDataSourcesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_data_source_with_http_info(body, container_id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_data_source_with_http_info(body, container_id, **kwargs)  # noqa: E501
            return data

    def create_data_source_with_http_info(self, body, container_id, **kwargs):  # noqa: E501
        """Create Data Source  # noqa: E501

        Create new datasource. Supported data source types are `http`, `standard` (or `manual`), `jazz`, and `aveva`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_data_source_with_http_info(body, container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateDataSourceRequest body: (required)
        :param str container_id: (required)
        :return: CreateDataSourcesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'container_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_data_source" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_data_source`")  # noqa: E501
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `create_data_source`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateDataSourcesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_manual_import(self, body, container_id, data_source_id, **kwargs):  # noqa: E501
        """Create Manual Import  # noqa: E501

        Create a manual import.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_manual_import(body, container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object body: (required)
        :param str container_id: (required)
        :param str data_source_id: (required)
        :return: CreateManualImportResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_manual_import_with_http_info(body, container_id, data_source_id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_manual_import_with_http_info(body, container_id, data_source_id, **kwargs)  # noqa: E501
            return data

    def create_manual_import_with_http_info(self, body, container_id, data_source_id, **kwargs):  # noqa: E501
        """Create Manual Import  # noqa: E501

        Create a manual import.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_manual_import_with_http_info(body, container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param object body: (required)
        :param str container_id: (required)
        :param str data_source_id: (required)
        :return: CreateManualImportResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'container_id', 'data_source_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_manual_import" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_manual_import`")  # noqa: E501
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `create_manual_import`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `create_manual_import`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}/imports', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateManualImportResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def download_file(self, container_id, file_id, **kwargs):  # noqa: E501
        """Download File  # noqa: E501

        Downloads a previously uploaded file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_file(container_id, file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str file_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.download_file_with_http_info(container_id, file_id, **kwargs)  # noqa: E501
        else:
            (data) = self.download_file_with_http_info(container_id, file_id, **kwargs)  # noqa: E501
            return data

    def download_file_with_http_info(self, container_id, file_id, **kwargs):  # noqa: E501
        """Download File  # noqa: E501

        Downloads a previously uploaded file.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_file_with_http_info(container_id, file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str file_id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'file_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `download_file`")  # noqa: E501
        # verify the required parameter 'file_id' is set
        if ('file_id' not in params or
                params['file_id'] is None):
            raise ValueError("Missing the required parameter `file_id` when calling `download_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'file_id' in params:
            path_params['file_id'] = params['file_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/files/{file_id}/download', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_data_sources(self, container_id, **kwargs):  # noqa: E501
        """List Data Sources  # noqa: E501

        List the datasources for the container.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_data_sources(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :return: ListDataSourcesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_data_sources_with_http_info(container_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_data_sources_with_http_info(container_id, **kwargs)  # noqa: E501
            return data

    def list_data_sources_with_http_info(self, container_id, **kwargs):  # noqa: E501
        """List Data Sources  # noqa: E501

        List the datasources for the container.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_data_sources_with_http_info(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :return: ListDataSourcesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_data_sources" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `list_data_sources`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListDataSourcesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_imports_for_data_source(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """List Imports for Data Source  # noqa: E501

        List the imports for the datasource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_imports_for_data_source(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :return: ListDataSourceImportsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_imports_for_data_source_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_imports_for_data_source_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
            return data

    def list_imports_for_data_source_with_http_info(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """List Imports for Data Source  # noqa: E501

        List the imports for the datasource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_imports_for_data_source_with_http_info(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :return: ListDataSourceImportsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'data_source_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_imports_for_data_source" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `list_imports_for_data_source`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `list_imports_for_data_source`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}/imports', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListDataSourceImportsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_data_source(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """Retrieve Data Source  # noqa: E501

        Retrieve a single data source by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_data_source(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :return: GetDataSourceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_data_source_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_data_source_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
            return data

    def retrieve_data_source_with_http_info(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """Retrieve Data Source  # noqa: E501

        Retrieve a single data source by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_data_source_with_http_info(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :return: GetDataSourceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'data_source_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_data_source" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `retrieve_data_source`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `retrieve_data_source`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetDataSourceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_file(self, container_id, file_id, **kwargs):  # noqa: E501
        """Retrieve File  # noqa: E501

        Get information about a file by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_file(container_id, file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str file_id: (required)
        :return: GetFileInfoResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_file_with_http_info(container_id, file_id, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_file_with_http_info(container_id, file_id, **kwargs)  # noqa: E501
            return data

    def retrieve_file_with_http_info(self, container_id, file_id, **kwargs):  # noqa: E501
        """Retrieve File  # noqa: E501

        Get information about a file by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_file_with_http_info(container_id, file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str file_id: (required)
        :return: GetFileInfoResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'file_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `retrieve_file`")  # noqa: E501
        # verify the required parameter 'file_id' is set
        if ('file_id' not in params or
                params['file_id'] is None):
            raise ValueError("Missing the required parameter `file_id` when calling `retrieve_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'file_id' in params:
            path_params['file_id'] = params['file_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/files/{file_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetFileInfoResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_data_source_active(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """Set Data Source Active  # noqa: E501

        Sets a data source active.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_data_source_active(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_data_source_active_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
        else:
            (data) = self.set_data_source_active_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
            return data

    def set_data_source_active_with_http_info(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """Set Data Source Active  # noqa: E501

        Sets a data source active.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_data_source_active_with_http_info(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'data_source_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_data_source_active" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `set_data_source_active`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `set_data_source_active`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}/active', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_data_source_configuration(self, body, container_id, data_source_id, **kwargs):  # noqa: E501
        """Set Data Source Configuration  # noqa: E501

        Updates a data source's configuration in storage. Note that this request body's structure must match that of the data source's adapter type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_data_source_configuration(body, container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateDataSourceConfig body: (required)
        :param str container_id: (required)
        :param str data_source_id: (required)
        :return: UpdateDataSourceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_data_source_configuration_with_http_info(body, container_id, data_source_id, **kwargs)  # noqa: E501
        else:
            (data) = self.set_data_source_configuration_with_http_info(body, container_id, data_source_id, **kwargs)  # noqa: E501
            return data

    def set_data_source_configuration_with_http_info(self, body, container_id, data_source_id, **kwargs):  # noqa: E501
        """Set Data Source Configuration  # noqa: E501

        Updates a data source's configuration in storage. Note that this request body's structure must match that of the data source's adapter type.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_data_source_configuration_with_http_info(body, container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateDataSourceConfig body: (required)
        :param str container_id: (required)
        :param str data_source_id: (required)
        :return: UpdateDataSourceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'container_id', 'data_source_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_data_source_configuration" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `set_data_source_configuration`")  # noqa: E501
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `set_data_source_configuration`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `set_data_source_configuration`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateDataSourceResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def set_data_source_inactive(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """Set Data Source Inactive  # noqa: E501

        Sets a data source inactive.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_data_source_inactive(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.set_data_source_inactive_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
        else:
            (data) = self.set_data_source_inactive_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
            return data

    def set_data_source_inactive_with_http_info(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """Set Data Source Inactive  # noqa: E501

        Sets a data source inactive.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_data_source_inactive_with_http_info(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'data_source_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_data_source_inactive" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `set_data_source_inactive`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `set_data_source_inactive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}/active', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload_file(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """Upload File  # noqa: E501

        Uploads a file and metadata to Deep Lynx. This endpoint will accept multiple files and multiple metadata properties as form values. If metadata (additional key value pairs) are provided, an import is created for the data source in addition to the file upload. Transformations can be applied to this import to create nodes and edges in the graph with metadata for the uploaded file(s).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_file(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str file:
        :return: UploadFileResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upload_file_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
        else:
            (data) = self.upload_file_with_http_info(container_id, data_source_id, **kwargs)  # noqa: E501
            return data

    def upload_file_with_http_info(self, container_id, data_source_id, **kwargs):  # noqa: E501
        """Upload File  # noqa: E501

        Uploads a file and metadata to Deep Lynx. This endpoint will accept multiple files and multiple metadata properties as form values. If metadata (additional key value pairs) are provided, an import is created for the data source in addition to the file upload. Transformations can be applied to this import to create nodes and edges in the graph with metadata for the uploaded file(s).  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_file_with_http_info(container_id, data_source_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str data_source_id: (required)
        :param str file:
        :return: UploadFileResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'data_source_id', 'file']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `upload_file`")  # noqa: E501
        # verify the required parameter 'data_source_id' is set
        if ('data_source_id' not in params or
                params['data_source_id'] is None):
            raise ValueError("Missing the required parameter `data_source_id` when calling `upload_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'data_source_id' in params:
            path_params['data_source_id'] = params['data_source_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'file' in params:
            form_params.append(('file', params['file']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/import/datasources/{data_source_id}/files', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UploadFileResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RelationshipPair(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'relationship_type': 'str',
        'relationship_id': 'str',
        'origin_metatype_id': 'str',
        'destination_metatype_id': 'str',
        'id': 'str',
        'archived': 'bool',
        'container_id': 'str',
        'created_at': 'str',
        'modified_at': 'str',
        'created_by': 'str',
        'modified_by': 'str',
        'origin_metatype_name': 'str',
        'destination_metatype_name': 'str',
        'relationship_pair_name': 'str',
        'destination_metatype': 'RelationshipPairDestinationMetatype',
        'origin_metatype': 'RelationshipPairDestinationMetatype',
        'relationship': 'RelationshipPairDestinationMetatype'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'relationship_type': 'relationship_type',
        'relationship_id': 'relationship_id',
        'origin_metatype_id': 'origin_metatype_id',
        'destination_metatype_id': 'destination_metatype_id',
        'id': 'id',
        'archived': 'archived',
        'container_id': 'container_id',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'created_by': 'created_by',
        'modified_by': 'modified_by',
        'origin_metatype_name': 'origin_metatype_name',
        'destination_metatype_name': 'destination_metatype_name',
        'relationship_pair_name': 'relationship_pair_name',
        'destination_metatype': 'destination_metatype',
        'origin_metatype': 'origin_metatype',
        'relationship': 'relationship'
    }

    def __init__(self, name=None, description=None, relationship_type=None, relationship_id=None, origin_metatype_id=None, destination_metatype_id=None, id=None, archived=None, container_id=None, created_at=None, modified_at=None, created_by=None, modified_by=None, origin_metatype_name=None, destination_metatype_name=None, relationship_pair_name=None, destination_metatype=None, origin_metatype=None, relationship=None):  # noqa: E501
        """RelationshipPair - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._description = None
        self._relationship_type = None
        self._relationship_id = None
        self._origin_metatype_id = None
        self._destination_metatype_id = None
        self._id = None
        self._archived = None
        self._container_id = None
        self._created_at = None
        self._modified_at = None
        self._created_by = None
        self._modified_by = None
        self._origin_metatype_name = None
        self._destination_metatype_name = None
        self._relationship_pair_name = None
        self._destination_metatype = None
        self._origin_metatype = None
        self._relationship = None
        self.discriminator = None
        self.name = name
        if description is not None:
            self.description = description
        if relationship_type is not None:
            self.relationship_type = relationship_type
        if relationship_id is not None:
            self.relationship_id = relationship_id
        if origin_metatype_id is not None:
            self.origin_metatype_id = origin_metatype_id
        if destination_metatype_id is not None:
            self.destination_metatype_id = destination_metatype_id
        self.id = id
        if archived is not None:
            self.archived = archived
        if container_id is not None:
            self.container_id = container_id
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if created_by is not None:
            self.created_by = created_by
        if modified_by is not None:
            self.modified_by = modified_by
        if origin_metatype_name is not None:
            self.origin_metatype_name = origin_metatype_name
        if destination_metatype_name is not None:
            self.destination_metatype_name = destination_metatype_name
        if relationship_pair_name is not None:
            self.relationship_pair_name = relationship_pair_name
        if destination_metatype is not None:
            self.destination_metatype = destination_metatype
        if origin_metatype is not None:
            self.origin_metatype = origin_metatype
        if relationship is not None:
            self.relationship = relationship

    @property
    def name(self):
        """Gets the name of this RelationshipPair.  # noqa: E501


        :return: The name of this RelationshipPair.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RelationshipPair.


        :param name: The name of this RelationshipPair.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this RelationshipPair.  # noqa: E501


        :return: The description of this RelationshipPair.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this RelationshipPair.


        :param description: The description of this RelationshipPair.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def relationship_type(self):
        """Gets the relationship_type of this RelationshipPair.  # noqa: E501


        :return: The relationship_type of this RelationshipPair.  # noqa: E501
        :rtype: str
        """
        return self._relationship_type

    @relationship_type.setter
    def relationship_type(self, relationship_type):
        """Sets the relationship_type of this RelationshipPair.


        :param relationship_type: The relationship_type of this RelationshipPair.  # noqa: E501
        :type: str
        """

        self._relationship_type = relationship_type

    @property
    def relationship_id(self):
        """Gets the relationship_id of this RelationshipPair.  # noqa: E501


        :return: The relationship_id of this RelationshipPair.  # noqa: E501
        :rtype: str
        """
        return self._relationship_id

    @relationship_id.setter
    def relationship_id(self, relationship_id):
        """Sets the relationship_id of this RelationshipPair.


        :param relationship_id: The relationship_id of this RelationshipPair.  # noqa: E501
        :type: str
        """

        self._relationship_id = relationship_id

    @property
    def origin_metatype_id(self):
        """Gets the origin_metatype_id of this RelationshipPair.  # noqa: E501


        :return: The origin_metatype_id of this RelationshipPair.  # noqa: E501
        :rtype: str
        """
        return self._origin_metatype_id

    @origin_metatype_id.setter
    def origin_metatype_id(self, origin_metatype_id):
        """Sets the origin_metatype_id of this RelationshipPair.


        :param origin_metatype_id: The origin_metatype_id of this RelationshipPair.  # noqa: E501
        :type: str
        """

        self._origin_metatype_id = origin_metatype_id

    @property
    def destination_metatype_id(self):
        """Gets the destination_metatype_id of this RelationshipPair.  # noqa: E501


        :return: The destination_metatype_id of this RelationshipPair.  # noqa: E501
        :rtype: str
        """
        return self._destination_metatype_id

    @destination_metatype_id.setter
    def destination_metatype_id(self, destination_metatype_id):
        """Sets the destination_metatype_id of this RelationshipPair.


        :param destination_metatype_id: The destination_metatype_id of this RelationshipPair.  # noqa: E501
        :type: str
        """

        self._destination_metatype_id = destination_metatype_id

    @property
    def id(self):
        """Gets the id of this RelationshipPair.  # noqa: E501


        :return: The id of this RelationshipPair.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RelationshipPair.


        :param id: The id of this RelationshipPair.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def archived(self):
        """Gets the archived of this RelationshipPair.  # noqa: E501


        :return: The archived of this RelationshipPair.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this RelationshipPair.


        :param archived: The archived of this RelationshipPair.  # noqa: E501
        :type: bool
        """

        self._archived = archived

    @property
    def container_id(self):
        """Gets the container_id of this RelationshipPair.  # noqa: E501


        :return: The container_id of this RelationshipPair.  # noqa: E501
        :rtype: str
        """
        return self._container_id

    @container_id.setter
    def container_id(self, container_id):
        """Sets the container_id of this RelationshipPair.


        :param container_id: The container_id of this RelationshipPair.  # noqa: E501
        :type: str
        """

        self._container_id = container_id

    @property
    def created_at(self):
        """Gets the created_at of this RelationshipPair.  # noqa: E501


        :return: The created_at of this RelationshipPair.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this RelationshipPair.


        :param created_at: The created_at of this RelationshipPair.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this RelationshipPair.  # noqa: E501


        :return: The modified_at of this RelationshipPair.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this RelationshipPair.


        :param modified_at: The modified_at of this RelationshipPair.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def created_by(self):
        """Gets the created_by of this RelationshipPair.  # noqa: E501


        :return: The created_by of this RelationshipPair.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this RelationshipPair.


        :param created_by: The created_by of this RelationshipPair.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this RelationshipPair.  # noqa: E501


        :return: The modified_by of this RelationshipPair.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this RelationshipPair.


        :param modified_by: The modified_by of this RelationshipPair.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def origin_metatype_name(self):
        """Gets the origin_metatype_name of this RelationshipPair.  # noqa: E501


        :return: The origin_metatype_name of this RelationshipPair.  # noqa: E501
        :rtype: str
        """
        return self._origin_metatype_name

    @origin_metatype_name.setter
    def origin_metatype_name(self, origin_metatype_name):
        """Sets the origin_metatype_name of this RelationshipPair.


        :param origin_metatype_name: The origin_metatype_name of this RelationshipPair.  # noqa: E501
        :type: str
        """

        self._origin_metatype_name = origin_metatype_name

    @property
    def destination_metatype_name(self):
        """Gets the destination_metatype_name of this RelationshipPair.  # noqa: E501


        :return: The destination_metatype_name of this RelationshipPair.  # noqa: E501
        :rtype: str
        """
        return self._destination_metatype_name

    @destination_metatype_name.setter
    def destination_metatype_name(self, destination_metatype_name):
        """Sets the destination_metatype_name of this RelationshipPair.


        :param destination_metatype_name: The destination_metatype_name of this RelationshipPair.  # noqa: E501
        :type: str
        """

        self._destination_metatype_name = destination_metatype_name

    @property
    def relationship_pair_name(self):
        """Gets the relationship_pair_name of this RelationshipPair.  # noqa: E501


        :return: The relationship_pair_name of this RelationshipPair.  # noqa: E501
        :rtype: str
        """
        return self._relationship_pair_name

    @relationship_pair_name.setter
    def relationship_pair_name(self, relationship_pair_name):
        """Sets the relationship_pair_name of this RelationshipPair.


        :param relationship_pair_name: The relationship_pair_name of this RelationshipPair.  # noqa: E501
        :type: str
        """

        self._relationship_pair_name = relationship_pair_name

    @property
    def destination_metatype(self):
        """Gets the destination_metatype of this RelationshipPair.  # noqa: E501


        :return: The destination_metatype of this RelationshipPair.  # noqa: E501
        :rtype: RelationshipPairDestinationMetatype
        """
        return self._destination_metatype

    @destination_metatype.setter
    def destination_metatype(self, destination_metatype):
        """Sets the destination_metatype of this RelationshipPair.


        :param destination_metatype: The destination_metatype of this RelationshipPair.  # noqa: E501
        :type: RelationshipPairDestinationMetatype
        """

        self._destination_metatype = destination_metatype

    @property
    def origin_metatype(self):
        """Gets the origin_metatype of this RelationshipPair.  # noqa: E501


        :return: The origin_metatype of this RelationshipPair.  # noqa: E501
        :rtype: RelationshipPairDestinationMetatype
        """
        return self._origin_metatype

    @origin_metatype.setter
    def origin_metatype(self, origin_metatype):
        """Sets the origin_metatype of this RelationshipPair.


        :param origin_metatype: The origin_metatype of this RelationshipPair.  # noqa: E501
        :type: RelationshipPairDestinationMetatype
        """

        self._origin_metatype = origin_metatype

    @property
    def relationship(self):
        """Gets the relationship of this RelationshipPair.  # noqa: E501


        :return: The relationship of this RelationshipPair.  # noqa: E501
        :rtype: RelationshipPairDestinationMetatype
        """
        return self._relationship

    @relationship.setter
    def relationship(self, relationship):
        """Sets the relationship of this RelationshipPair.


        :param relationship: The relationship of this RelationshipPair.  # noqa: E501
        :type: RelationshipPairDestinationMetatype
        """

        self._relationship = relationship

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RelationshipPair, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RelationshipPair):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.graph_api import GraphApi  # noqa: E501
from swagger_client.rest import ApiException


class TestGraphApi(unittest.TestCase):
    """GraphApi unit test stubs"""

    def setUp(self):
        self.api = GraphApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_archive_edge(self):
        """Test case for archive_edge

        ArchiveEdge  # noqa: E501
        """
        pass

    def test_archive_node(self):
        """Test case for archive_node

        ArchiveNode  # noqa: E501
        """
        pass

    def test_attach_edge_file(self):
        """Test case for attach_edge_file

        AttachEdgeFile  # noqa: E501
        """
        pass

    def test_attach_node_file(self):
        """Test case for attach_node_file

        AttachNodeFile  # noqa: E501
        """
        pass

    def test_create_or_update_edges(self):
        """Test case for create_or_update_edges

        CreateOrUpdateEdges  # noqa: E501
        """
        pass

    def test_create_or_update_nodes(self):
        """Test case for create_or_update_nodes

        CreateOrUpdateNodes  # noqa: E501
        """
        pass

    def test_delete_node_file(self):
        """Test case for delete_node_file

        DeleteNodeFile  # noqa: E501
        """
        pass

    def test_detach_node_file(self):
        """Test case for detach_node_file

        DetachNodeFile  # noqa: E501
        """
        pass

    def test_list_edge_files(self):
        """Test case for list_edge_files

        ListEdgeFiles  # noqa: E501
        """
        pass

    def test_list_edges(self):
        """Test case for list_edges

        ListEdges  # noqa: E501
        """
        pass

    def test_list_node_files(self):
        """Test case for list_node_files

        ListNodeFiles  # noqa: E501
        """
        pass

    def test_list_nodes(self):
        """Test case for list_nodes

        ListNodes  # noqa: E501
        """
        pass

    def test_list_nodesby_metatype_id(self):
        """Test case for list_nodesby_metatype_id

        ListNodesbyMetatypeID  # noqa: E501
        """
        pass

    def test_retrieve_edge(self):
        """Test case for retrieve_edge

        RetrieveEdge  # noqa: E501
        """
        pass

    def test_retrieve_node(self):
        """Test case for retrieve_node

        RetrieveNode  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Event(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'active': 'bool',
        'id': 'str',
        'app_name': 'str',
        'app_url': 'str',
        'data_source_id': 'str',
        'container_id': 'str',
        'event_type': 'str',
        'created_at': 'str',
        'modified_at': 'str',
        'created_by': 'str',
        'modified_by': 'str'
    }

    attribute_map = {
        'active': 'active',
        'id': 'id',
        'app_name': 'app_name',
        'app_url': 'app_url',
        'data_source_id': 'data_source_id',
        'container_id': 'container_id',
        'event_type': 'event_type',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'created_by': 'created_by',
        'modified_by': 'modified_by'
    }

    def __init__(self, active=None, id=None, app_name=None, app_url=None, data_source_id=None, container_id=None, event_type=None, created_at=None, modified_at=None, created_by=None, modified_by=None):  # noqa: E501
        """Event - a model defined in Swagger"""  # noqa: E501
        self._active = None
        self._id = None
        self._app_name = None
        self._app_url = None
        self._data_source_id = None
        self._container_id = None
        self._event_type = None
        self._created_at = None
        self._modified_at = None
        self._created_by = None
        self._modified_by = None
        self.discriminator = None
        if active is not None:
            self.active = active
        if id is not None:
            self.id = id
        self.app_name = app_name
        self.app_url = app_url
        if data_source_id is not None:
            self.data_source_id = data_source_id
        if container_id is not None:
            self.container_id = container_id
        self.event_type = event_type
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if created_by is not None:
            self.created_by = created_by
        if modified_by is not None:
            self.modified_by = modified_by

    @property
    def active(self):
        """Gets the active of this Event.  # noqa: E501


        :return: The active of this Event.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this Event.


        :param active: The active of this Event.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def id(self):
        """Gets the id of this Event.  # noqa: E501


        :return: The id of this Event.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Event.


        :param id: The id of this Event.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def app_name(self):
        """Gets the app_name of this Event.  # noqa: E501


        :return: The app_name of this Event.  # noqa: E501
        :rtype: str
        """
        return self._app_name

    @app_name.setter
    def app_name(self, app_name):
        """Sets the app_name of this Event.


        :param app_name: The app_name of this Event.  # noqa: E501
        :type: str
        """
        if app_name is None:
            raise ValueError("Invalid value for `app_name`, must not be `None`")  # noqa: E501

        self._app_name = app_name

    @property
    def app_url(self):
        """Gets the app_url of this Event.  # noqa: E501


        :return: The app_url of this Event.  # noqa: E501
        :rtype: str
        """
        return self._app_url

    @app_url.setter
    def app_url(self, app_url):
        """Sets the app_url of this Event.


        :param app_url: The app_url of this Event.  # noqa: E501
        :type: str
        """
        if app_url is None:
            raise ValueError("Invalid value for `app_url`, must not be `None`")  # noqa: E501

        self._app_url = app_url

    @property
    def data_source_id(self):
        """Gets the data_source_id of this Event.  # noqa: E501


        :return: The data_source_id of this Event.  # noqa: E501
        :rtype: str
        """
        return self._data_source_id

    @data_source_id.setter
    def data_source_id(self, data_source_id):
        """Sets the data_source_id of this Event.


        :param data_source_id: The data_source_id of this Event.  # noqa: E501
        :type: str
        """

        self._data_source_id = data_source_id

    @property
    def container_id(self):
        """Gets the container_id of this Event.  # noqa: E501


        :return: The container_id of this Event.  # noqa: E501
        :rtype: str
        """
        return self._container_id

    @container_id.setter
    def container_id(self, container_id):
        """Sets the container_id of this Event.


        :param container_id: The container_id of this Event.  # noqa: E501
        :type: str
        """

        self._container_id = container_id

    @property
    def event_type(self):
        """Gets the event_type of this Event.  # noqa: E501


        :return: The event_type of this Event.  # noqa: E501
        :rtype: str
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        """Sets the event_type of this Event.


        :param event_type: The event_type of this Event.  # noqa: E501
        :type: str
        """
        if event_type is None:
            raise ValueError("Invalid value for `event_type`, must not be `None`")  # noqa: E501

        self._event_type = event_type

    @property
    def created_at(self):
        """Gets the created_at of this Event.  # noqa: E501


        :return: The created_at of this Event.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Event.


        :param created_at: The created_at of this Event.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this Event.  # noqa: E501


        :return: The modified_at of this Event.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this Event.


        :param modified_at: The modified_at of this Event.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def created_by(self):
        """Gets the created_by of this Event.  # noqa: E501


        :return: The created_by of this Event.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Event.


        :param created_by: The created_by of this Event.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this Event.  # noqa: E501


        :return: The modified_by of this Event.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this Event.


        :param modified_by: The modified_by of this Event.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Event, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Event):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.models.new_metatype_request import NewMetatypeRequest  # noqa: E501
from swagger_client.rest import ApiException


class TestNewMetatypeRequest(unittest.TestCase):
    """NewMetatypeRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testNewMetatypeRequest(self):
        """Test NewMetatypeRequest"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.new_metatype_request.NewMetatypeRequest()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RelationshipKey(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'description': 'str',
        'property_name': 'str',
        'data_type': 'str',
        'required': 'bool',
        'cardinality': 'float',
        'validation': 'Validation',
        'unique': 'bool',
        'options': 'list[object]',
        'default_value': 'str',
        'metatype_relationship_id': 'str',
        'id': 'str',
        'archived': 'bool',
        'created_at': 'str',
        'modified_at': 'str',
        'created_by': 'str',
        'modified_by': 'str'
    }

    attribute_map = {
        'name': 'name',
        'description': 'description',
        'property_name': 'property_name',
        'data_type': 'data_type',
        'required': 'required',
        'cardinality': 'cardinality',
        'validation': 'validation',
        'unique': 'unique',
        'options': 'options',
        'default_value': 'defaultValue',
        'metatype_relationship_id': 'metatype_relationship_id',
        'id': 'id',
        'archived': 'archived',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'created_by': 'created_by',
        'modified_by': 'modified_by'
    }

    def __init__(self, name=None, description=None, property_name=None, data_type=None, required=None, cardinality=None, validation=None, unique=None, options=None, default_value=None, metatype_relationship_id=None, id=None, archived=None, created_at=None, modified_at=None, created_by=None, modified_by=None):  # noqa: E501
        """RelationshipKey - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._description = None
        self._property_name = None
        self._data_type = None
        self._required = None
        self._cardinality = None
        self._validation = None
        self._unique = None
        self._options = None
        self._default_value = None
        self._metatype_relationship_id = None
        self._id = None
        self._archived = None
        self._created_at = None
        self._modified_at = None
        self._created_by = None
        self._modified_by = None
        self.discriminator = None
        self.name = name
        self.description = description
        self.property_name = property_name
        self.data_type = data_type
        self.required = required
        self.cardinality = cardinality
        self.validation = validation
        self.unique = unique
        if options is not None:
            self.options = options
        if default_value is not None:
            self.default_value = default_value
        self.metatype_relationship_id = metatype_relationship_id
        self.id = id
        self.archived = archived
        self.created_at = created_at
        self.modified_at = modified_at
        self.created_by = created_by
        self.modified_by = modified_by

    @property
    def name(self):
        """Gets the name of this RelationshipKey.  # noqa: E501


        :return: The name of this RelationshipKey.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RelationshipKey.


        :param name: The name of this RelationshipKey.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def description(self):
        """Gets the description of this RelationshipKey.  # noqa: E501


        :return: The description of this RelationshipKey.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this RelationshipKey.


        :param description: The description of this RelationshipKey.  # noqa: E501
        :type: str
        """
        if description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def property_name(self):
        """Gets the property_name of this RelationshipKey.  # noqa: E501


        :return: The property_name of this RelationshipKey.  # noqa: E501
        :rtype: str
        """
        return self._property_name

    @property_name.setter
    def property_name(self, property_name):
        """Sets the property_name of this RelationshipKey.


        :param property_name: The property_name of this RelationshipKey.  # noqa: E501
        :type: str
        """
        if property_name is None:
            raise ValueError("Invalid value for `property_name`, must not be `None`")  # noqa: E501

        self._property_name = property_name

    @property
    def data_type(self):
        """Gets the data_type of this RelationshipKey.  # noqa: E501


        :return: The data_type of this RelationshipKey.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this RelationshipKey.


        :param data_type: The data_type of this RelationshipKey.  # noqa: E501
        :type: str
        """
        if data_type is None:
            raise ValueError("Invalid value for `data_type`, must not be `None`")  # noqa: E501

        self._data_type = data_type

    @property
    def required(self):
        """Gets the required of this RelationshipKey.  # noqa: E501


        :return: The required of this RelationshipKey.  # noqa: E501
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this RelationshipKey.


        :param required: The required of this RelationshipKey.  # noqa: E501
        :type: bool
        """
        if required is None:
            raise ValueError("Invalid value for `required`, must not be `None`")  # noqa: E501

        self._required = required

    @property
    def cardinality(self):
        """Gets the cardinality of this RelationshipKey.  # noqa: E501


        :return: The cardinality of this RelationshipKey.  # noqa: E501
        :rtype: float
        """
        return self._cardinality

    @cardinality.setter
    def cardinality(self, cardinality):
        """Sets the cardinality of this RelationshipKey.


        :param cardinality: The cardinality of this RelationshipKey.  # noqa: E501
        :type: float
        """
        if cardinality is None:
            raise ValueError("Invalid value for `cardinality`, must not be `None`")  # noqa: E501

        self._cardinality = cardinality

    @property
    def validation(self):
        """Gets the validation of this RelationshipKey.  # noqa: E501


        :return: The validation of this RelationshipKey.  # noqa: E501
        :rtype: Validation
        """
        return self._validation

    @validation.setter
    def validation(self, validation):
        """Sets the validation of this RelationshipKey.


        :param validation: The validation of this RelationshipKey.  # noqa: E501
        :type: Validation
        """
        if validation is None:
            raise ValueError("Invalid value for `validation`, must not be `None`")  # noqa: E501

        self._validation = validation

    @property
    def unique(self):
        """Gets the unique of this RelationshipKey.  # noqa: E501


        :return: The unique of this RelationshipKey.  # noqa: E501
        :rtype: bool
        """
        return self._unique

    @unique.setter
    def unique(self, unique):
        """Sets the unique of this RelationshipKey.


        :param unique: The unique of this RelationshipKey.  # noqa: E501
        :type: bool
        """
        if unique is None:
            raise ValueError("Invalid value for `unique`, must not be `None`")  # noqa: E501

        self._unique = unique

    @property
    def options(self):
        """Gets the options of this RelationshipKey.  # noqa: E501


        :return: The options of this RelationshipKey.  # noqa: E501
        :rtype: list[object]
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this RelationshipKey.


        :param options: The options of this RelationshipKey.  # noqa: E501
        :type: list[object]
        """

        self._options = options

    @property
    def default_value(self):
        """Gets the default_value of this RelationshipKey.  # noqa: E501


        :return: The default_value of this RelationshipKey.  # noqa: E501
        :rtype: str
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """Sets the default_value of this RelationshipKey.


        :param default_value: The default_value of this RelationshipKey.  # noqa: E501
        :type: str
        """

        self._default_value = default_value

    @property
    def metatype_relationship_id(self):
        """Gets the metatype_relationship_id of this RelationshipKey.  # noqa: E501


        :return: The metatype_relationship_id of this RelationshipKey.  # noqa: E501
        :rtype: str
        """
        return self._metatype_relationship_id

    @metatype_relationship_id.setter
    def metatype_relationship_id(self, metatype_relationship_id):
        """Sets the metatype_relationship_id of this RelationshipKey.


        :param metatype_relationship_id: The metatype_relationship_id of this RelationshipKey.  # noqa: E501
        :type: str
        """
        if metatype_relationship_id is None:
            raise ValueError("Invalid value for `metatype_relationship_id`, must not be `None`")  # noqa: E501

        self._metatype_relationship_id = metatype_relationship_id

    @property
    def id(self):
        """Gets the id of this RelationshipKey.  # noqa: E501


        :return: The id of this RelationshipKey.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RelationshipKey.


        :param id: The id of this RelationshipKey.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def archived(self):
        """Gets the archived of this RelationshipKey.  # noqa: E501


        :return: The archived of this RelationshipKey.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this RelationshipKey.


        :param archived: The archived of this RelationshipKey.  # noqa: E501
        :type: bool
        """
        if archived is None:
            raise ValueError("Invalid value for `archived`, must not be `None`")  # noqa: E501

        self._archived = archived

    @property
    def created_at(self):
        """Gets the created_at of this RelationshipKey.  # noqa: E501


        :return: The created_at of this RelationshipKey.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this RelationshipKey.


        :param created_at: The created_at of this RelationshipKey.  # noqa: E501
        :type: str
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this RelationshipKey.  # noqa: E501


        :return: The modified_at of this RelationshipKey.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this RelationshipKey.


        :param modified_at: The modified_at of this RelationshipKey.  # noqa: E501
        :type: str
        """
        if modified_at is None:
            raise ValueError("Invalid value for `modified_at`, must not be `None`")  # noqa: E501

        self._modified_at = modified_at

    @property
    def created_by(self):
        """Gets the created_by of this RelationshipKey.  # noqa: E501


        :return: The created_by of this RelationshipKey.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this RelationshipKey.


        :param created_by: The created_by of this RelationshipKey.  # noqa: E501
        :type: str
        """
        if created_by is None:
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this RelationshipKey.  # noqa: E501


        :return: The modified_by of this RelationshipKey.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this RelationshipKey.


        :param modified_by: The modified_by of this RelationshipKey.  # noqa: E501
        :type: str
        """
        if modified_by is None:
            raise ValueError("Invalid value for `modified_by`, must not be `None`")  # noqa: E501

        self._modified_by = modified_by

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RelationshipKey, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RelationshipKey):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from swagger_client.api.authentication_api import AuthenticationApi
from swagger_client.api.containers_api import ContainersApi
from swagger_client.api.data_export_api import DataExportApi
from swagger_client.api.data_query_api import DataQueryApi
from swagger_client.api.data_sources_api import DataSourcesApi
from swagger_client.api.data_type_mappings_api import DataTypeMappingsApi
from swagger_client.api.events_api import EventsApi
from swagger_client.api.graph_api import GraphApi
from swagger_client.api.imports_api import ImportsApi
from swagger_client.api.metatype_keys_api import MetatypeKeysApi
from swagger_client.api.metatype_relationship_keys_api import MetatypeRelationshipKeysApi
from swagger_client.api.metatype_relationship_pairs_api import MetatypeRelationshipPairsApi
from swagger_client.api.metatype_relationships_api import MetatypeRelationshipsApi
from swagger_client.api.metatypes_api import MetatypesApi
from swagger_client.api.misc_api import MiscApi
from swagger_client.api.users_api import UsersApi



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Transformation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'conditions': 'list[TransformationCondition]',
        'keys': 'list[TransformationKey]',
        'id': 'str',
        'type_mapping_id': 'str',
        'metatype_id': 'str',
        'metatype_relationship_pair_id': 'str',
        'origin_id_key': 'str',
        'destination_id_key': 'str',
        'unique_identifier_key': 'str',
        'root_array': 'str',
        'created_at': 'str',
        'modified_at': 'str',
        'created_by': 'str',
        'modified_by': 'str',
        'archived': 'bool',
        'metatype_name': 'str',
        'metatype_relationship_pair_name': 'str',
        'container_id': 'str',
        'shape_hash': 'str',
        'data_source_id': 'str'
    }

    attribute_map = {
        'conditions': 'conditions',
        'keys': 'keys',
        'id': 'id',
        'type_mapping_id': 'type_mapping_id',
        'metatype_id': 'metatype_id',
        'metatype_relationship_pair_id': 'metatype_relationship_pair_id',
        'origin_id_key': 'origin_id_key',
        'destination_id_key': 'destination_id_key',
        'unique_identifier_key': 'unique_identifier_key',
        'root_array': 'root_array',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'created_by': 'created_by',
        'modified_by': 'modified_by',
        'archived': 'archived',
        'metatype_name': 'metatype_name',
        'metatype_relationship_pair_name': 'metatype_relationship_pair_name',
        'container_id': 'container_id',
        'shape_hash': 'shape_hash',
        'data_source_id': 'data_source_id'
    }

    def __init__(self, conditions=None, keys=None, id=None, type_mapping_id=None, metatype_id=None, metatype_relationship_pair_id=None, origin_id_key=None, destination_id_key=None, unique_identifier_key=None, root_array=None, created_at=None, modified_at=None, created_by=None, modified_by=None, archived=None, metatype_name=None, metatype_relationship_pair_name=None, container_id=None, shape_hash=None, data_source_id=None):  # noqa: E501
        """Transformation - a model defined in Swagger"""  # noqa: E501
        self._conditions = None
        self._keys = None
        self._id = None
        self._type_mapping_id = None
        self._metatype_id = None
        self._metatype_relationship_pair_id = None
        self._origin_id_key = None
        self._destination_id_key = None
        self._unique_identifier_key = None
        self._root_array = None
        self._created_at = None
        self._modified_at = None
        self._created_by = None
        self._modified_by = None
        self._archived = None
        self._metatype_name = None
        self._metatype_relationship_pair_name = None
        self._container_id = None
        self._shape_hash = None
        self._data_source_id = None
        self.discriminator = None
        self.conditions = conditions
        self.keys = keys
        if id is not None:
            self.id = id
        if type_mapping_id is not None:
            self.type_mapping_id = type_mapping_id
        if metatype_id is not None:
            self.metatype_id = metatype_id
        if metatype_relationship_pair_id is not None:
            self.metatype_relationship_pair_id = metatype_relationship_pair_id
        if origin_id_key is not None:
            self.origin_id_key = origin_id_key
        if destination_id_key is not None:
            self.destination_id_key = destination_id_key
        if unique_identifier_key is not None:
            self.unique_identifier_key = unique_identifier_key
        if root_array is not None:
            self.root_array = root_array
        if created_at is not None:
            self.created_at = created_at
        if modified_at is not None:
            self.modified_at = modified_at
        if created_by is not None:
            self.created_by = created_by
        if modified_by is not None:
            self.modified_by = modified_by
        self.archived = archived
        if metatype_name is not None:
            self.metatype_name = metatype_name
        if metatype_relationship_pair_name is not None:
            self.metatype_relationship_pair_name = metatype_relationship_pair_name
        if container_id is not None:
            self.container_id = container_id
        if shape_hash is not None:
            self.shape_hash = shape_hash
        if data_source_id is not None:
            self.data_source_id = data_source_id

    @property
    def conditions(self):
        """Gets the conditions of this Transformation.  # noqa: E501


        :return: The conditions of this Transformation.  # noqa: E501
        :rtype: list[TransformationCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this Transformation.


        :param conditions: The conditions of this Transformation.  # noqa: E501
        :type: list[TransformationCondition]
        """
        if conditions is None:
            raise ValueError("Invalid value for `conditions`, must not be `None`")  # noqa: E501

        self._conditions = conditions

    @property
    def keys(self):
        """Gets the keys of this Transformation.  # noqa: E501


        :return: The keys of this Transformation.  # noqa: E501
        :rtype: list[TransformationKey]
        """
        return self._keys

    @keys.setter
    def keys(self, keys):
        """Sets the keys of this Transformation.


        :param keys: The keys of this Transformation.  # noqa: E501
        :type: list[TransformationKey]
        """
        if keys is None:
            raise ValueError("Invalid value for `keys`, must not be `None`")  # noqa: E501

        self._keys = keys

    @property
    def id(self):
        """Gets the id of this Transformation.  # noqa: E501


        :return: The id of this Transformation.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Transformation.


        :param id: The id of this Transformation.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def type_mapping_id(self):
        """Gets the type_mapping_id of this Transformation.  # noqa: E501


        :return: The type_mapping_id of this Transformation.  # noqa: E501
        :rtype: str
        """
        return self._type_mapping_id

    @type_mapping_id.setter
    def type_mapping_id(self, type_mapping_id):
        """Sets the type_mapping_id of this Transformation.


        :param type_mapping_id: The type_mapping_id of this Transformation.  # noqa: E501
        :type: str
        """

        self._type_mapping_id = type_mapping_id

    @property
    def metatype_id(self):
        """Gets the metatype_id of this Transformation.  # noqa: E501


        :return: The metatype_id of this Transformation.  # noqa: E501
        :rtype: str
        """
        return self._metatype_id

    @metatype_id.setter
    def metatype_id(self, metatype_id):
        """Sets the metatype_id of this Transformation.


        :param metatype_id: The metatype_id of this Transformation.  # noqa: E501
        :type: str
        """

        self._metatype_id = metatype_id

    @property
    def metatype_relationship_pair_id(self):
        """Gets the metatype_relationship_pair_id of this Transformation.  # noqa: E501


        :return: The metatype_relationship_pair_id of this Transformation.  # noqa: E501
        :rtype: str
        """
        return self._metatype_relationship_pair_id

    @metatype_relationship_pair_id.setter
    def metatype_relationship_pair_id(self, metatype_relationship_pair_id):
        """Sets the metatype_relationship_pair_id of this Transformation.


        :param metatype_relationship_pair_id: The metatype_relationship_pair_id of this Transformation.  # noqa: E501
        :type: str
        """

        self._metatype_relationship_pair_id = metatype_relationship_pair_id

    @property
    def origin_id_key(self):
        """Gets the origin_id_key of this Transformation.  # noqa: E501


        :return: The origin_id_key of this Transformation.  # noqa: E501
        :rtype: str
        """
        return self._origin_id_key

    @origin_id_key.setter
    def origin_id_key(self, origin_id_key):
        """Sets the origin_id_key of this Transformation.


        :param origin_id_key: The origin_id_key of this Transformation.  # noqa: E501
        :type: str
        """

        self._origin_id_key = origin_id_key

    @property
    def destination_id_key(self):
        """Gets the destination_id_key of this Transformation.  # noqa: E501


        :return: The destination_id_key of this Transformation.  # noqa: E501
        :rtype: str
        """
        return self._destination_id_key

    @destination_id_key.setter
    def destination_id_key(self, destination_id_key):
        """Sets the destination_id_key of this Transformation.


        :param destination_id_key: The destination_id_key of this Transformation.  # noqa: E501
        :type: str
        """

        self._destination_id_key = destination_id_key

    @property
    def unique_identifier_key(self):
        """Gets the unique_identifier_key of this Transformation.  # noqa: E501


        :return: The unique_identifier_key of this Transformation.  # noqa: E501
        :rtype: str
        """
        return self._unique_identifier_key

    @unique_identifier_key.setter
    def unique_identifier_key(self, unique_identifier_key):
        """Sets the unique_identifier_key of this Transformation.


        :param unique_identifier_key: The unique_identifier_key of this Transformation.  # noqa: E501
        :type: str
        """

        self._unique_identifier_key = unique_identifier_key

    @property
    def root_array(self):
        """Gets the root_array of this Transformation.  # noqa: E501


        :return: The root_array of this Transformation.  # noqa: E501
        :rtype: str
        """
        return self._root_array

    @root_array.setter
    def root_array(self, root_array):
        """Sets the root_array of this Transformation.


        :param root_array: The root_array of this Transformation.  # noqa: E501
        :type: str
        """

        self._root_array = root_array

    @property
    def created_at(self):
        """Gets the created_at of this Transformation.  # noqa: E501


        :return: The created_at of this Transformation.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Transformation.


        :param created_at: The created_at of this Transformation.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this Transformation.  # noqa: E501


        :return: The modified_at of this Transformation.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this Transformation.


        :param modified_at: The modified_at of this Transformation.  # noqa: E501
        :type: str
        """

        self._modified_at = modified_at

    @property
    def created_by(self):
        """Gets the created_by of this Transformation.  # noqa: E501


        :return: The created_by of this Transformation.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Transformation.


        :param created_by: The created_by of this Transformation.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this Transformation.  # noqa: E501


        :return: The modified_by of this Transformation.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this Transformation.


        :param modified_by: The modified_by of this Transformation.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def archived(self):
        """Gets the archived of this Transformation.  # noqa: E501


        :return: The archived of this Transformation.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this Transformation.


        :param archived: The archived of this Transformation.  # noqa: E501
        :type: bool
        """
        if archived is None:
            raise ValueError("Invalid value for `archived`, must not be `None`")  # noqa: E501

        self._archived = archived

    @property
    def metatype_name(self):
        """Gets the metatype_name of this Transformation.  # noqa: E501


        :return: The metatype_name of this Transformation.  # noqa: E501
        :rtype: str
        """
        return self._metatype_name

    @metatype_name.setter
    def metatype_name(self, metatype_name):
        """Sets the metatype_name of this Transformation.


        :param metatype_name: The metatype_name of this Transformation.  # noqa: E501
        :type: str
        """

        self._metatype_name = metatype_name

    @property
    def metatype_relationship_pair_name(self):
        """Gets the metatype_relationship_pair_name of this Transformation.  # noqa: E501


        :return: The metatype_relationship_pair_name of this Transformation.  # noqa: E501
        :rtype: str
        """
        return self._metatype_relationship_pair_name

    @metatype_relationship_pair_name.setter
    def metatype_relationship_pair_name(self, metatype_relationship_pair_name):
        """Sets the metatype_relationship_pair_name of this Transformation.


        :param metatype_relationship_pair_name: The metatype_relationship_pair_name of this Transformation.  # noqa: E501
        :type: str
        """

        self._metatype_relationship_pair_name = metatype_relationship_pair_name

    @property
    def container_id(self):
        """Gets the container_id of this Transformation.  # noqa: E501


        :return: The container_id of this Transformation.  # noqa: E501
        :rtype: str
        """
        return self._container_id

    @container_id.setter
    def container_id(self, container_id):
        """Sets the container_id of this Transformation.


        :param container_id: The container_id of this Transformation.  # noqa: E501
        :type: str
        """

        self._container_id = container_id

    @property
    def shape_hash(self):
        """Gets the shape_hash of this Transformation.  # noqa: E501


        :return: The shape_hash of this Transformation.  # noqa: E501
        :rtype: str
        """
        return self._shape_hash

    @shape_hash.setter
    def shape_hash(self, shape_hash):
        """Sets the shape_hash of this Transformation.


        :param shape_hash: The shape_hash of this Transformation.  # noqa: E501
        :type: str
        """

        self._shape_hash = shape_hash

    @property
    def data_source_id(self):
        """Gets the data_source_id of this Transformation.  # noqa: E501


        :return: The data_source_id of this Transformation.  # noqa: E501
        :rtype: str
        """
        return self._data_source_id

    @data_source_id.setter
    def data_source_id(self, data_source_id):
        """Sets the data_source_id of this Transformation.


        :param data_source_id: The data_source_id of this Transformation.  # noqa: E501
        :type: str
        """

        self._data_source_id = data_source_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Transformation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Transformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class MetatypeKeysApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive_metatype_key(self, container_id, metatype_id, key_id, **kwargs):  # noqa: E501
        """ArchiveMetatypeKey  # noqa: E501

        Archiving the metatype key prevents any new types from implementing the key. It *does not remove key/value pairs on existing types*. We highly recommend you archive type keys instead of deleting them so that previous data is not affected.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_metatype_key(container_id, metatype_id, key_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str metatype_id: (required)
        :param str key_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.archive_metatype_key_with_http_info(container_id, metatype_id, key_id, **kwargs)  # noqa: E501
        else:
            (data) = self.archive_metatype_key_with_http_info(container_id, metatype_id, key_id, **kwargs)  # noqa: E501
            return data

    def archive_metatype_key_with_http_info(self, container_id, metatype_id, key_id, **kwargs):  # noqa: E501
        """ArchiveMetatypeKey  # noqa: E501

        Archiving the metatype key prevents any new types from implementing the key. It *does not remove key/value pairs on existing types*. We highly recommend you archive type keys instead of deleting them so that previous data is not affected.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_metatype_key_with_http_info(container_id, metatype_id, key_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str metatype_id: (required)
        :param str key_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'metatype_id', 'key_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_metatype_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `archive_metatype_key`")  # noqa: E501
        # verify the required parameter 'metatype_id' is set
        if ('metatype_id' not in params or
                params['metatype_id'] is None):
            raise ValueError("Missing the required parameter `metatype_id` when calling `archive_metatype_key`")  # noqa: E501
        # verify the required parameter 'key_id' is set
        if ('key_id' not in params or
                params['key_id'] is None):
            raise ValueError("Missing the required parameter `key_id` when calling `archive_metatype_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'metatype_id' in params:
            path_params['metatype_id'] = params['metatype_id']  # noqa: E501
        if 'key_id' in params:
            path_params['key_id'] = params['key_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/metatypes/{metatype_id}/keys/{key_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_metatype_key(self, body, container_id, metatype_id, **kwargs):  # noqa: E501
        """CreateMetatypeKey  # noqa: E501

        Creates a new key for a metatype. Keys consist of a unique key name (unique to the metatype only), key type, default values, and allowed values. Of those, only the first two are required.  The `dataType` field accepts only one of the following values: number, string, date, boolean, enumeration, file.   The fields `defaultValue` and `options` will only accept an array of the following types: string, boolean, number, float.  Pass in an array for bulk creation.  Currently the validation and cardinality functionality of keys are NOT checked at data insertion.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_metatype_key(body, container_id, metatype_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NewMetatypeKeyRequest body: (required)
        :param str container_id: (required)
        :param str metatype_id: (required)
        :return: CreateMetatypeKeysResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_metatype_key_with_http_info(body, container_id, metatype_id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_metatype_key_with_http_info(body, container_id, metatype_id, **kwargs)  # noqa: E501
            return data

    def create_metatype_key_with_http_info(self, body, container_id, metatype_id, **kwargs):  # noqa: E501
        """CreateMetatypeKey  # noqa: E501

        Creates a new key for a metatype. Keys consist of a unique key name (unique to the metatype only), key type, default values, and allowed values. Of those, only the first two are required.  The `dataType` field accepts only one of the following values: number, string, date, boolean, enumeration, file.   The fields `defaultValue` and `options` will only accept an array of the following types: string, boolean, number, float.  Pass in an array for bulk creation.  Currently the validation and cardinality functionality of keys are NOT checked at data insertion.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_metatype_key_with_http_info(body, container_id, metatype_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NewMetatypeKeyRequest body: (required)
        :param str container_id: (required)
        :param str metatype_id: (required)
        :return: CreateMetatypeKeysResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'container_id', 'metatype_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_metatype_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_metatype_key`")  # noqa: E501
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `create_metatype_key`")  # noqa: E501
        # verify the required parameter 'metatype_id' is set
        if ('metatype_id' not in params or
                params['metatype_id'] is None):
            raise ValueError("Missing the required parameter `metatype_id` when calling `create_metatype_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'metatype_id' in params:
            path_params['metatype_id'] = params['metatype_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/metatypes/{metatype_id}/keys', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateMetatypeKeysResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_metatypes_keys(self, container_id, metatype_id, **kwargs):  # noqa: E501
        """ListMetatypesKeys  # noqa: E501

        Lists all currently valid and available keys for the metatype.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_metatypes_keys(container_id, metatype_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str metatype_id: (required)
        :return: ListMetatypeKeysResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_metatypes_keys_with_http_info(container_id, metatype_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_metatypes_keys_with_http_info(container_id, metatype_id, **kwargs)  # noqa: E501
            return data

    def list_metatypes_keys_with_http_info(self, container_id, metatype_id, **kwargs):  # noqa: E501
        """ListMetatypesKeys  # noqa: E501

        Lists all currently valid and available keys for the metatype.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_metatypes_keys_with_http_info(container_id, metatype_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str metatype_id: (required)
        :return: ListMetatypeKeysResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'metatype_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_metatypes_keys" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `list_metatypes_keys`")  # noqa: E501
        # verify the required parameter 'metatype_id' is set
        if ('metatype_id' not in params or
                params['metatype_id'] is None):
            raise ValueError("Missing the required parameter `metatype_id` when calling `list_metatypes_keys`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'metatype_id' in params:
            path_params['metatype_id'] = params['metatype_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/metatypes/{metatype_id}/keys', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListMetatypeKeysResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_metatype_key(self, container_id, metatype_id, key_id, **kwargs):  # noqa: E501
        """RetrieveMetatypeKey  # noqa: E501

        Retrieve the specified key for the metatype.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_metatype_key(container_id, metatype_id, key_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str metatype_id: (required)
        :param str key_id: (required)
        :return: GetMetatypeKeyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_metatype_key_with_http_info(container_id, metatype_id, key_id, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_metatype_key_with_http_info(container_id, metatype_id, key_id, **kwargs)  # noqa: E501
            return data

    def retrieve_metatype_key_with_http_info(self, container_id, metatype_id, key_id, **kwargs):  # noqa: E501
        """RetrieveMetatypeKey  # noqa: E501

        Retrieve the specified key for the metatype.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_metatype_key_with_http_info(container_id, metatype_id, key_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str metatype_id: (required)
        :param str key_id: (required)
        :return: GetMetatypeKeyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'metatype_id', 'key_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_metatype_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `retrieve_metatype_key`")  # noqa: E501
        # verify the required parameter 'metatype_id' is set
        if ('metatype_id' not in params or
                params['metatype_id'] is None):
            raise ValueError("Missing the required parameter `metatype_id` when calling `retrieve_metatype_key`")  # noqa: E501
        # verify the required parameter 'key_id' is set
        if ('key_id' not in params or
                params['key_id'] is None):
            raise ValueError("Missing the required parameter `key_id` when calling `retrieve_metatype_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'metatype_id' in params:
            path_params['metatype_id'] = params['metatype_id']  # noqa: E501
        if 'key_id' in params:
            path_params['key_id'] = params['key_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/metatypes/{metatype_id}/keys/{key_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetMetatypeKeyResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_metatype_key(self, body, container_id, metatype_id, key_id, **kwargs):  # noqa: E501
        """UpdateMetatypeKey  # noqa: E501

        Updates a single key for a metatype.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_metatype_key(body, container_id, metatype_id, key_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateMetatypeKeyRequest body: (required)
        :param str container_id: (required)
        :param str metatype_id: (required)
        :param str key_id: (required)
        :return: UpdateMetatypeKeyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_metatype_key_with_http_info(body, container_id, metatype_id, key_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_metatype_key_with_http_info(body, container_id, metatype_id, key_id, **kwargs)  # noqa: E501
            return data

    def update_metatype_key_with_http_info(self, body, container_id, metatype_id, key_id, **kwargs):  # noqa: E501
        """UpdateMetatypeKey  # noqa: E501

        Updates a single key for a metatype.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_metatype_key_with_http_info(body, container_id, metatype_id, key_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UpdateMetatypeKeyRequest body: (required)
        :param str container_id: (required)
        :param str metatype_id: (required)
        :param str key_id: (required)
        :return: UpdateMetatypeKeyResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'container_id', 'metatype_id', 'key_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_metatype_key" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_metatype_key`")  # noqa: E501
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `update_metatype_key`")  # noqa: E501
        # verify the required parameter 'metatype_id' is set
        if ('metatype_id' not in params or
                params['metatype_id'] is None):
            raise ValueError("Missing the required parameter `metatype_id` when calling `update_metatype_key`")  # noqa: E501
        # verify the required parameter 'key_id' is set
        if ('key_id' not in params or
                params['key_id'] is None):
            raise ValueError("Missing the required parameter `key_id` when calling `update_metatype_key`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'metatype_id' in params:
            path_params['metatype_id'] = params['metatype_id']  # noqa: E501
        if 'key_id' in params:
            path_params['key_id'] = params['key_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/metatypes/{metatype_id}/keys/{key_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateMetatypeKeyResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FileInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'metadata': 'object',
        'id': 'str',
        'file_name': 'str',
        'file_size': 'float',
        'adapter_file_path': 'str',
        'adapter': 'str',
        'data_source_id': 'str',
        'created_at': 'str',
        'modified_at': 'str',
        'created_by': 'str',
        'modified_by': 'str',
        'container_id': 'str',
        'md5hash': 'str'
    }

    attribute_map = {
        'metadata': 'metadata',
        'id': 'id',
        'file_name': 'file_name',
        'file_size': 'file_size',
        'adapter_file_path': 'adapter_file_path',
        'adapter': 'adapter',
        'data_source_id': 'data_source_id',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'created_by': 'created_by',
        'modified_by': 'modified_by',
        'container_id': 'container_id',
        'md5hash': 'md5hash'
    }

    def __init__(self, metadata=None, id=None, file_name=None, file_size=None, adapter_file_path=None, adapter=None, data_source_id=None, created_at=None, modified_at=None, created_by=None, modified_by=None, container_id=None, md5hash=None):  # noqa: E501
        """FileInfo - a model defined in Swagger"""  # noqa: E501
        self._metadata = None
        self._id = None
        self._file_name = None
        self._file_size = None
        self._adapter_file_path = None
        self._adapter = None
        self._data_source_id = None
        self._created_at = None
        self._modified_at = None
        self._created_by = None
        self._modified_by = None
        self._container_id = None
        self._md5hash = None
        self.discriminator = None
        if metadata is not None:
            self.metadata = metadata
        self.id = id
        self.file_name = file_name
        self.file_size = file_size
        self.adapter_file_path = adapter_file_path
        self.adapter = adapter
        self.data_source_id = data_source_id
        self.created_at = created_at
        self.modified_at = modified_at
        self.created_by = created_by
        self.modified_by = modified_by
        self.container_id = container_id
        self.md5hash = md5hash

    @property
    def metadata(self):
        """Gets the metadata of this FileInfo.  # noqa: E501


        :return: The metadata of this FileInfo.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this FileInfo.


        :param metadata: The metadata of this FileInfo.  # noqa: E501
        :type: object
        """

        self._metadata = metadata

    @property
    def id(self):
        """Gets the id of this FileInfo.  # noqa: E501


        :return: The id of this FileInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FileInfo.


        :param id: The id of this FileInfo.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def file_name(self):
        """Gets the file_name of this FileInfo.  # noqa: E501


        :return: The file_name of this FileInfo.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this FileInfo.


        :param file_name: The file_name of this FileInfo.  # noqa: E501
        :type: str
        """
        if file_name is None:
            raise ValueError("Invalid value for `file_name`, must not be `None`")  # noqa: E501

        self._file_name = file_name

    @property
    def file_size(self):
        """Gets the file_size of this FileInfo.  # noqa: E501


        :return: The file_size of this FileInfo.  # noqa: E501
        :rtype: float
        """
        return self._file_size

    @file_size.setter
    def file_size(self, file_size):
        """Sets the file_size of this FileInfo.


        :param file_size: The file_size of this FileInfo.  # noqa: E501
        :type: float
        """
        if file_size is None:
            raise ValueError("Invalid value for `file_size`, must not be `None`")  # noqa: E501

        self._file_size = file_size

    @property
    def adapter_file_path(self):
        """Gets the adapter_file_path of this FileInfo.  # noqa: E501


        :return: The adapter_file_path of this FileInfo.  # noqa: E501
        :rtype: str
        """
        return self._adapter_file_path

    @adapter_file_path.setter
    def adapter_file_path(self, adapter_file_path):
        """Sets the adapter_file_path of this FileInfo.


        :param adapter_file_path: The adapter_file_path of this FileInfo.  # noqa: E501
        :type: str
        """
        if adapter_file_path is None:
            raise ValueError("Invalid value for `adapter_file_path`, must not be `None`")  # noqa: E501

        self._adapter_file_path = adapter_file_path

    @property
    def adapter(self):
        """Gets the adapter of this FileInfo.  # noqa: E501


        :return: The adapter of this FileInfo.  # noqa: E501
        :rtype: str
        """
        return self._adapter

    @adapter.setter
    def adapter(self, adapter):
        """Sets the adapter of this FileInfo.


        :param adapter: The adapter of this FileInfo.  # noqa: E501
        :type: str
        """
        if adapter is None:
            raise ValueError("Invalid value for `adapter`, must not be `None`")  # noqa: E501

        self._adapter = adapter

    @property
    def data_source_id(self):
        """Gets the data_source_id of this FileInfo.  # noqa: E501


        :return: The data_source_id of this FileInfo.  # noqa: E501
        :rtype: str
        """
        return self._data_source_id

    @data_source_id.setter
    def data_source_id(self, data_source_id):
        """Sets the data_source_id of this FileInfo.


        :param data_source_id: The data_source_id of this FileInfo.  # noqa: E501
        :type: str
        """
        if data_source_id is None:
            raise ValueError("Invalid value for `data_source_id`, must not be `None`")  # noqa: E501

        self._data_source_id = data_source_id

    @property
    def created_at(self):
        """Gets the created_at of this FileInfo.  # noqa: E501


        :return: The created_at of this FileInfo.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this FileInfo.


        :param created_at: The created_at of this FileInfo.  # noqa: E501
        :type: str
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this FileInfo.  # noqa: E501


        :return: The modified_at of this FileInfo.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this FileInfo.


        :param modified_at: The modified_at of this FileInfo.  # noqa: E501
        :type: str
        """
        if modified_at is None:
            raise ValueError("Invalid value for `modified_at`, must not be `None`")  # noqa: E501

        self._modified_at = modified_at

    @property
    def created_by(self):
        """Gets the created_by of this FileInfo.  # noqa: E501


        :return: The created_by of this FileInfo.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this FileInfo.


        :param created_by: The created_by of this FileInfo.  # noqa: E501
        :type: str
        """
        if created_by is None:
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this FileInfo.  # noqa: E501


        :return: The modified_by of this FileInfo.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this FileInfo.


        :param modified_by: The modified_by of this FileInfo.  # noqa: E501
        :type: str
        """
        if modified_by is None:
            raise ValueError("Invalid value for `modified_by`, must not be `None`")  # noqa: E501

        self._modified_by = modified_by

    @property
    def container_id(self):
        """Gets the container_id of this FileInfo.  # noqa: E501


        :return: The container_id of this FileInfo.  # noqa: E501
        :rtype: str
        """
        return self._container_id

    @container_id.setter
    def container_id(self, container_id):
        """Sets the container_id of this FileInfo.


        :param container_id: The container_id of this FileInfo.  # noqa: E501
        :type: str
        """
        if container_id is None:
            raise ValueError("Invalid value for `container_id`, must not be `None`")  # noqa: E501

        self._container_id = container_id

    @property
    def md5hash(self):
        """Gets the md5hash of this FileInfo.  # noqa: E501


        :return: The md5hash of this FileInfo.  # noqa: E501
        :rtype: str
        """
        return self._md5hash

    @md5hash.setter
    def md5hash(self, md5hash):
        """Sets the md5hash of this FileInfo.


        :param md5hash: The md5hash of this FileInfo.  # noqa: E501
        :type: str
        """
        if md5hash is None:
            raise ValueError("Invalid value for `md5hash`, must not be `None`")  # noqa: E501

        self._md5hash = md5hash

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FileInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.data_sources_api import DataSourcesApi  # noqa: E501
from swagger_client.rest import ApiException


class TestDataSourcesApi(unittest.TestCase):
    """DataSourcesApi unit test stubs"""

    def setUp(self):
        self.api = DataSourcesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_archive_data_source(self):
        """Test case for archive_data_source

        ArchiveDataSource  # noqa: E501
        """
        pass

    def test_create_data_source(self):
        """Test case for create_data_source

        CreateDataSource  # noqa: E501
        """
        pass

    def test_create_manual_import(self):
        """Test case for create_manual_import

        CreateManualImport  # noqa: E501
        """
        pass

    def test_download_file(self):
        """Test case for download_file

        DownloadFile  # noqa: E501
        """
        pass

    def test_list_data_sources(self):
        """Test case for list_data_sources

        ListDataSources  # noqa: E501
        """
        pass

    def test_list_imports_for_data_source(self):
        """Test case for list_imports_for_data_source

        ListImportsForDataSource  # noqa: E501
        """
        pass

    def test_retrieve_data_source(self):
        """Test case for retrieve_data_source

        RetrieveDataSource  # noqa: E501
        """
        pass

    def test_retrieve_file(self):
        """Test case for retrieve_file

        RetrieveFile  # noqa: E501
        """
        pass

    def test_set_data_source_active(self):
        """Test case for set_data_source_active

        SetDataSourceActive  # noqa: E501
        """
        pass

    def test_set_data_source_configuration(self):
        """Test case for set_data_source_configuration

        SetDataSourceConfiguration  # noqa: E501
        """
        pass

    def test_set_data_source_inactive(self):
        """Test case for set_data_source_inactive

        SetDataSourceInactive  # noqa: E501
        """
        pass

    def test_upload_file(self):
        """Test case for upload_file

        UploadFile  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
